@@ -30,11 +30,15 @@ public:
         AvatarPressedRole,
         LoaderPressedRole
 #endif
+        ,ServiceRole
     };
 
 public:
     explicit AbstractCommentListModel(QObject *parent = 0);
     ~AbstractCommentListModel();
+#if QT_VERSION >= 0x050000
+    QHash<int, QByteArray> roleNames() const;
+#endif
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
     QVariant data(const QModelIndex &index, int role) const;
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
@@ -67,6 +71,7 @@ protected:
     int m_loaderPressedRow;
 #endif
     QList< QSharedPointer<CommentItem> > m_list;
+    QHash<int, QByteArray> m_roleNames;
 };
 
 #endif // ABSTRACTCOMMENTLISTMODEL_H
