@@ -9,21 +9,24 @@ AbstractUserListModel::AbstractUserListModel(QObject *parent) :
     ,m_cache(new ThumbnailCache)
   #endif
 {
-    QHash<int, QByteArray> roles;
-    roles[IdRole] = "id";
-    roles[SubscriptionIdRole] = "subscriptionId";
-    roles[UsernameRole] = "username";
-    roles[ChannelNameRole] = "channelName";
+    m_roleNames[IdRole] = "id";
+    m_roleNames[SubscriptionIdRole] = "subscriptionId";
+    m_roleNames[UsernameRole] = "username";
+    m_roleNames[ChannelNameRole] = "channelName";
 #ifndef QML_USER_INTERFACE
-    roles[AvatarRole] = "avatar";
+    m_roleNames[AvatarRole] = "avatar";
 #endif
-    roles[AvatarUrlRole] = "avatarUrl";
-    roles[VideoCountRole] = "videoCount";
-    roles[DescriptionRole] = "description";
-    roles[ViewCountRole] = "viewCount";
-    roles[SubscriberCountRole] = "subscriberCount";
-    roles[SubscriptionRole] = "subscription";
-    this->setRoleNames(roles);
+    m_roleNames[AvatarUrlRole] = "avatarUrl";
+    m_roleNames[VideoCountRole] = "videoCount";
+    m_roleNames[DescriptionRole] = "description";
+    m_roleNames[ViewCountRole] = "viewCount";
+    m_roleNames[SubscriberCountRole] = "subscriberCount";
+    m_roleNames[SubscriptionRole] = "subscription";
+    m_roleNames[ServiceRole] = "service";
+#if QT_VERSION < 0x050000
+    this->setRoleNames(m_roleNames);
+#endif
+
 #ifndef QML_USER_INTERFACE
     this->connect(m_cache, SIGNAL(thumbnailReady()), this, SLOT(onThumbnailReady()));
 #endif
@@ -37,6 +40,12 @@ AbstractUserListModel::~AbstractUserListModel() {
 #endif
 }
 
+#if QT_VERSION >= 0x050000
+QHash<int, QByteArray> AbstractUserListModel::roleNames() const {
+    return m_roleNames;
+}
+#endif
+
 void AbstractUserListModel::clear() {
     this->beginResetModel();
     m_list.clear();
@@ -71,6 +80,8 @@ QVariant AbstractUserListModel::data(const QModelIndex &index, int role) const {
         return m_list.at(index.row()).data()->subscriberCount();
     case SubscriptionRole:
         return m_list.at(index.row()).data()->subscription();
+    case ServiceRole:
+        return m_list.at(index.row()).data()->service();
     default:
         return QVariant();
     }
