@@ -11,7 +11,7 @@
 #include <QTimer>
 #endif
 
-ClipboardMonitor* monitorInstance = 0;
+ClipboardMonitor* ClipboardMonitor::self = 0;
 
 ClipboardMonitor::ClipboardMonitor(QObject *parent) :
     QObject(parent)
@@ -19,8 +19,8 @@ ClipboardMonitor::ClipboardMonitor(QObject *parent) :
   ,m_timer(0)
   #endif
 {
-    if (!monitorInstance) {
-        monitorInstance = this;
+    if (!self) {
+        self = this;
     }
 #if QT_VERSION >= 0x050000
     this->connect(QGuiApplication::clipboard(), SIGNAL(dataChanged()), this, SLOT(onClipboardTextChanged()));
@@ -30,7 +30,7 @@ ClipboardMonitor::ClipboardMonitor(QObject *parent) :
 }
 
 ClipboardMonitor* ClipboardMonitor::instance() {
-    return monitorInstance;
+    return !self ? new ClipboardMonitor : self;
 }
 
 void ClipboardMonitor::onClipboardTextChanged() {
@@ -50,11 +50,11 @@ void ClipboardMonitor::onClipboardTextChanged() {
     }
 #endif
 #if QT_VERSION >= 0x050000
-    if (QGuiApplication::clipboard()->text().contains(QRegExp("((http://(www.|m.|)youtube.com/(v/|.+)(v=|list=|)|http://youtu.be/))|((http(s|)://(www.|)dailymotion.com/(video|playlist)/|http://dai.ly/)\\w{6})|(http://vimeo.com/\\d+)"))) {
+    if (QGuiApplication::clipboard()->text().contains(QRegExp("((http(s|)://(www.|m.|)youtube.com/(v/|.+)(v=|list=|)|http://youtu.be/))|((http(s|)://(www.|)dailymotion.com/(video|playlist)/|http://dai.ly/)\\w+)|(http(s|)://vimeo.com/\\d+)"))) {
         this->setClipboardUrl(QGuiApplication::clipboard()->text());
     }
 #else
-    if (QApplication::clipboard()->text().contains(QRegExp("((http://(www.|m.|)youtube.com/(v/|.+)(v=|list=|)|http://youtu.be/))|((http(s|)://(www.|)dailymotion.com/(video|playlist)/|http://dai.ly/)\\w{6})|(http://vimeo.com/\\d+)"))) {
+    if (QApplication::clipboard()->text().contains(QRegExp("((http(s|)://(www.|m.|)youtube.com/(v/|.+)(v=|list=|)|http://youtu.be/))|((http(s|)://(www.|)dailymotion.com/(video|playlist)/|http://dai.ly/)\\w+)|(http(s|)://vimeo.com/\\d+)"))) {
         this->setClipboardUrl(QApplication::clipboard()->text());
     }
 #endif
