@@ -5,6 +5,9 @@
 #include <QNetworkReply>
 #include <QNetworkRequest>
 #include <QTimer>
+#if QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
 
 using namespace QtJson;
 
@@ -45,9 +48,13 @@ void DailymotionUserListModel::getUsers(QUrl feed) {
     else {
         feed = this->feed();
     }
-
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("fields", DAILYMOTION_USER_FIELDS);
+    feed.setQuery(query);
+#else
     feed.addQueryItem("fields", DAILYMOTION_USER_FIELDS);
-
+#endif
     this->setLoading(true);
     QNetworkReply *reply = Dailymotion::instance()->createReply(feed, this->offset());
     reply->setParent(this);
