@@ -1,17 +1,8 @@
 #ifndef DATABASE_H
 #define DATABASE_H
 
-#include <qplatformdefs.h>
+#include <QObject>
 #include <QSqlDatabase>
-#ifdef MEEGO_EDITION_HARMATTAN
-#include "../harmattan/transferitem.h"
-#elif (defined (Q_WS_MAEMO_5))
-#include "../maemo5_gui/transferitem.h"
-#elif (defined (SYMBIAN_OS))
-#include "../symbian/transferitem.h"
-#elif (defined (Q_OS_UNIX))
-#include "../tv/transferitem.h"
-#endif
 
 class Database : public QObject
 {
@@ -26,10 +17,6 @@ public:
 
 public slots:
     void initialize();
-    QList< QSharedPointer<TransferItem> > getStoredDownloads();
-    bool storeDownload(QSharedPointer<TransferItem> transfer);
-    bool removeStoredDownload(const QString &id);
-    bool updateStoredDownload(const QString &id, const QString &key, const QVariant &value);
     bool setYouTubeUsername(const QString &user);
     bool setYouTubeAccessToken(const QString &token);
     bool setDailymotionUsername(const QString &user);
@@ -59,6 +46,8 @@ private:
     void restoreTwitterAccount();
 
 private:
+    static Database *self;
+
     QSqlDatabase m_database;
 };
 
