@@ -2,6 +2,9 @@
 #include <QDateTime>
 #include <QCryptographicHash>
 #include <QStringList>
+#if QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
 
 namespace QtOAuth {
 
@@ -52,7 +55,12 @@ QByteArray OAuth::createSignature(QByteArray key, QByteArray baseString) {
 }
 
 QByteArray OAuth::createOAuthHeader(const QString &method, const QUrl &url, QMap<QString, QString> params) {
+#if QT_VERSION >= 0x050000
+    QUrlQuery urlQuery(url);
+    QList< QPair<QString, QString> > queryItems = urlQuery.queryItems();
+#else
     QList< QPair<QString, QString> > queryItems = url.queryItems();
+#endif
     QString nonce(OAuth::getNonce());
     QString timeStamp(OAuth::getTimeStamp());
 
