@@ -1,6 +1,6 @@
 #include "screensaver.h"
 
-#ifndef Q_WS_SAILFISH
+#ifndef SAILFISH_OS
 ScreenSaver::ScreenSaver(QObject *parent) :
     QObject(parent)
 {
