@@ -13,10 +13,14 @@ public:
 #if QT_VERSION >= 0x050000
     QHash<int, QByteArray> roleNames() const;
 #endif
-    void addItem(const QString &name, const QVariant &value);
+    Q_INVOKABLE void addItem(const QString &name, const QVariant &value);
+    Q_INVOKABLE bool removeItem(int row);
+
     Q_INVOKABLE QString name(int row) const;
     Q_INVOKABLE QVariant value(int row) const;
+
     Q_INVOKABLE QVariantMap get(int row) const;
+
     Q_INVOKABLE inline Qt::Alignment textAlignment() const { return m_textAlignment; }
     Q_INVOKABLE inline void setTextAlignment(Qt::Alignment alignment) { m_textAlignment = alignment; }
 
@@ -276,6 +280,21 @@ signals:
     void countChanged(int count);
 };
 
+class ConnectionsModel : public SelectionModel
+{
+    Q_OBJECT
+
+    Q_PROPERTY(int count
+               READ rowCount
+               NOTIFY countChanged)
+
+public:
+    explicit ConnectionsModel(QObject *parent = 0);
+
+signals:
+    void countChanged(int count);
+};
+
 class NetworkProxyTypeModel : public SelectionModel
 {
     Q_OBJECT
