@@ -47,6 +47,9 @@ public:
 public:
     explicit SocialVideoListModel(QObject *parent = 0);
     ~SocialVideoListModel();
+#if QT_VERSION >= 0x050000
+    QHash<int, QByteArray> roleNames() const;
+#endif
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
     QSharedPointer<VideoItem> get(int row) const;
@@ -83,6 +86,7 @@ private:
     int m_thumbnailPressedRow;
 #endif
     QList<int> m_selectedRows;
+    QHash<int, QByteArray> m_roleNames;
 };
 
 #endif // SOCIALVIDEOLISTMODEL_H
