@@ -429,7 +429,7 @@ void UrlGrabber::checkYouTubeVideoInfoPage() {
 }
 
 void UrlGrabber::getYouTubeVideoWebPage(const QString &id, const char *slot) {
-    QUrl url("http://www.youtube.com/watch");
+    QUrl url("https://www.youtube.com/watch");
 #if QT_VERSION >= 0x050000
     QUrlQuery query;
     query.addQueryItem("v", id);
@@ -444,7 +444,7 @@ void UrlGrabber::getYouTubeVideoWebPage(const QString &id, const char *slot) {
     url.addQueryItem("has_verified", "1");
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; Linux x86_64; rv:28.0) Gecko/20100101  Firefox/28.0");
+    request.setRawHeader("User-Agent", "Wget/1.13.4 (linux-gnu)");
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, slot);
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
