@@ -4,6 +4,9 @@
 #include <QNetworkReply>
 #include <QNetworkRequest>
 #include <QTimer>
+#if QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
 
 YouTubeUserListModel::YouTubeUserListModel(QObject *parent) :
     AbstractUserListModel(parent),
@@ -44,9 +47,13 @@ void YouTubeUserListModel::getUsers(QUrl feed) {
     else {
         feed = this->feed();
     }
-
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(feed);
+    query.addQueryItem("fields", m_subscriptions ? YOUTUBE_SUBSCRIPTION_FIELDS : YOUTUBE_USER_FIELDS);
+    feed.setQuery(query);
+#else
     feed.addQueryItem("fields", m_subscriptions ? YOUTUBE_SUBSCRIPTION_FIELDS : YOUTUBE_USER_FIELDS);
-
+#endif
     this->setLoading(true);
     QNetworkReply *reply = YouTube::instance()->createReply(feed, this->offset());
     reply->setParent(this);
