@@ -22,6 +22,9 @@ class YouTubeVideoListModel : public AbstractVideoListModel
                READ feed
                WRITE setFeed
                NOTIFY feedChanged)
+    Q_PROPERTY(QString playlistId
+               READ playlistId
+               NOTIFY feedChanged)
     Q_PROPERTY(bool refreshRequired
                READ refreshRequired
                NOTIFY refreshRequiredChanged)
