@@ -1,5 +1,5 @@
 #include "archivevideolistdelegate.h"
-#include "../base/archivelistmodel.h"
+#include "archivelistmodel.h"
 #include <QApplication>
 #include <QStaticText>
 #include <QPainter>
