@@ -4,7 +4,6 @@
 #include "abstractdialog.h"
 #include "../base/videoitem.h"
 
-class Session;
 class QTextEdit;
 class QPushButton;
 class QDialogButtonBox;
@@ -16,7 +15,7 @@ class DailymotionCommentDialog : public AbstractDialog
     Q_OBJECT
 
 public:
-    explicit DailymotionCommentDialog(Session *session, QSharedPointer<VideoItem> video, QWidget *parent = 0);
+    explicit DailymotionCommentDialog(QSharedPointer<VideoItem> video, QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
@@ -27,7 +26,6 @@ private slots:
     void submitComment();
 
 private:
-    Session *m_session;
     QSharedPointer<VideoItem> m_video;
     QTextEdit *m_commentEdit;
     QDialogButtonBox *m_buttonBox;
