@@ -4,7 +4,6 @@
 #include "abstracttab.h"
 #include "../base/groupitem.h"
 
-class Session;
 class ListView;
 class DailymotionGroupListModel;
 class QLabel;
@@ -16,8 +15,8 @@ class DailymotionGroupListTab : public AbstractTab
     Q_OBJECT
 
 public:
-    explicit DailymotionGroupListTab(Session *session, QWidget *parent = 0);
-    void setGroupFeed(const QString &feed);
+    explicit DailymotionGroupListTab(QWidget *parent = 0);
+    void setGroupFeed(const QUrl &feed);
 
 private:
     void setLandscapeLayout();
@@ -30,7 +29,6 @@ private slots:
     void showGroup(QSharedPointer<GroupItem> group);
 
 private:
-    Session *m_session;
     ListView *m_listView;
     DailymotionGroupListModel *m_model;
     QLabel *m_noResultsLabel;
