@@ -3,7 +3,6 @@
 
 #include "stackedwindow.h"
 
-class Session;
 class DailymotionProfileTab;
 class DailymotionVideoListTab;
 class DailymotionUserPlaylistListTab;
@@ -18,7 +17,7 @@ class DailymotionMyChannelWindow : public StackedWindow
     Q_OBJECT
 
 public:
-    explicit DailymotionMyChannelWindow(Session *session, QWidget *parent);
+    explicit DailymotionMyChannelWindow(QWidget *parent);
 
 private:
     void clearMenuActions();
