@@ -4,7 +4,6 @@
 #include "stackedwindow.h"
 #include "../base/playlistitem.h"
 
-class Session;
 class DailymotionPlaylistListModel;
 class ListView;
 class QLabel;
@@ -14,8 +13,8 @@ class DailymotionPlaylistListWindow : public StackedWindow
 {
     Q_OBJECT
 public:
-    explicit DailymotionPlaylistListWindow(Session *session, QWidget *parent);
-    void setPlaylistFeed(const QString &feed);
+    explicit DailymotionPlaylistListWindow(QWidget *parent);
+    void setPlaylistFeed(const QUrl &feed);
     void search(const QString &query, Queries::QueryOrder order);
 
 private:
