@@ -1,30 +1,22 @@
 #ifndef NAVBUTTON_H
 #define NAVBUTTON_H
 
-#include <QWidget>
+#include <QAbstractButton>
 #include <QMouseEvent>
 #include <QPaintEvent>
 
-class NavButton : public QWidget
+class NavButton : public QAbstractButton
 {
     Q_OBJECT
+
 public:
     explicit NavButton(const QString &text, const QString &iconSource, QWidget *parent = 0);
 
 protected:
-    void mousePressEvent(QMouseEvent *event);
-    void mouseReleaseEvent(QMouseEvent *event);
-    void leaveEvent(QEvent *event);
     void paintEvent(QPaintEvent *event);
 
-    
-signals:
-    void clicked();
-    
 private:
-    QString m_text;
     QImage m_icon;
-    bool m_pressed;
 };
 
 #endif // NAVBUTTON_H
