@@ -208,24 +208,34 @@ void TransferDetailsDialog::onTransferStatusChanged(Transfers::Status status) {
 
     switch (status) {
     case Transfers::Downloading:
-        m_statusIcon->setPixmap(QPixmap("/usr/share/icons/hicolor/48x48/hildon/as_proxy_attachment_download.png"));
+        m_statusIcon->setPixmap(QPixmap("/usr/share/icons/hicolor/48x48/hildon/general_received.png"));
         m_pauseResumeButton->setText(tr("Pause"));
+        m_pauseResumeButton->setEnabled(true);
+        break;
+    case Transfers::Uploading:
+        m_statusIcon->setPixmap(QPixmap("/usr/share/icons/hicolor/48x48/hildon/general_sent.png"));
+        m_pauseResumeButton->setText(tr("Pause"));
+        m_pauseResumeButton->setEnabled(false);
         break;
     case Transfers::Connecting:
         m_statusIcon->setPixmap(QPixmap("/usr/share/icons/hicolor/48x48/hildon/general_packetdata.png"));
         m_pauseResumeButton->setText(tr("Pause"));
+        m_pauseResumeButton->setEnabled(true);
         break;
     case Transfers::Paused:
         m_statusIcon->setPixmap(QPixmap("/etc/hildon/theme/mediaplayer/Pause.png"));
         m_pauseResumeButton->setText(tr("Start"));
+        m_pauseResumeButton->setEnabled(true);
         break;
     case Transfers::Converting:
         m_statusIcon->setPixmap(QPixmap("/usr/share/icons/hicolor/48x48/hildon/general_audio_file.png"));
         m_pauseResumeButton->setText(tr("Pause"));
+        m_pauseResumeButton->setEnabled(true);
         break;
     case Transfers::Failed:
         m_statusIcon->setPixmap(QPixmap("/usr/share/icons/hicolor/48x48/hildon/general_stop.png"));
         m_pauseResumeButton->setText(tr("Start"));
+        m_pauseResumeButton->setEnabled(true);
         break;
     case Transfers::Completed:
         this->accept();
@@ -236,6 +246,7 @@ void TransferDetailsDialog::onTransferStatusChanged(Transfers::Status status) {
     default:
         m_statusIcon->setPixmap(QPixmap("/etc/hildon/theme/mediaplayer/Stop.png"));
         m_pauseResumeButton->setText(tr("Pause"));
+        m_pauseResumeButton->setEnabled(true);
     }
 }
 
