@@ -3,7 +3,6 @@
 
 #include "abstractdialog.h"
 
-class Session;
 class WebView;
 class QProgressBar;
 class QGridLayout;
@@ -14,7 +13,7 @@ class TwitterAuthDialog : public AbstractDialog
     Q_OBJECT
 
 public:
-    explicit TwitterAuthDialog(Session *session, QWidget *parent = 0);
+    explicit TwitterAuthDialog(QWidget *parent = 0);
 
 private:
     inline void setLandscapeLayout() { this->setFixedHeight(340); }
@@ -25,7 +24,6 @@ private slots:
     void checkUrlForToken(const QUrl &url);
         
 private:
-    Session *m_session;
     WebView *m_webView;
     QProgressBar *m_progressBar;
     QGridLayout *m_grid;
