@@ -4,9 +4,11 @@
 #include "../base/youtube.h"
 #include "../base/notifications.h"
 #include "../base/thumbnailcache.h"
+#include "../base/utils.h"
 #include "windowstack.h"
 #include "separatorlabel.h"
 #include "avatarlabel.h"
+#include "resourceloader.h"
 #include <QLabel>
 #include <QPushButton>
 #include <QScrollArea>
@@ -54,6 +56,7 @@ YouTubeProfileTab::YouTubeProfileTab(const QString &userId, QWidget *parent) :
     m_scrollArea->setWidgetResizable(true);
     m_scrollArea->setWidget(scrollWidget);
     m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    m_websiteLabel->setOpenExternalLinks(true);
     m_descriptionLabel->setWordWrap(true);
     m_scrollArea->hide();
     m_noProfileLabel->hide();
@@ -65,7 +68,7 @@ YouTubeProfileTab::YouTubeProfileTab(const QString &userId, QWidget *parent) :
 
     this->connect(YouTube::instance(), SIGNAL(gotUser(QSharedPointer<UserItem>)), this, SLOT(setUser(QSharedPointer<UserItem>)));
     this->connect(YouTube::instance(), SIGNAL(error(QString)), this, SLOT(onProfileError()));
-    this->connect(m_websiteLabel, SIGNAL(linkActivated(QString)), this, SLOT(showUserWebsite()));
+    this->connect(m_descriptionLabel, SIGNAL(linkActivated(QString)), this, SLOT(parseActivatedLink(QString)));
     this->connect(m_subscriptionButton, SIGNAL(clicked()), this, SLOT(toggleSubscription()));
 
     if ((userId == "me") || (userId == YouTube::instance()->username())) {
@@ -104,7 +107,7 @@ void YouTubeProfileTab::setUser(QSharedPointer<UserItem> user) {
     m_subscribersLabel->setText(!m_user.data()->subscriberCount() ? tr("No subscribers") : QString("%1 %2").arg(m_user.data()->subscriberCount()).arg(tr("subscribers")));
     m_locationLabel->setText(QString("%1: %2").arg(tr("Location")).arg(m_user.data()->location().isEmpty() ? tr("Unknown") : m_user.data()->location()));
     m_websiteLabel->setText(m_user.data()->websiteUrl().isEmpty() ? tr("No website") : QString("%1: <a href='%2'>%2</a>").arg("Website").arg(m_user.data()->websiteUrl().toString()));
-    m_descriptionLabel->setText(m_user.data()->description().isEmpty() ? tr("No description") : m_user.data()->description());
+    m_descriptionLabel->setText(m_user.data()->description().isEmpty() ? tr("No description") : Utils::toRichText(m_user.data()->description()));
     m_subscriptionButton->setText(m_user.data()->subscribed() ? tr("Unsubscribe") : tr("Subscribe"));
 
     m_scrollArea->show();
@@ -147,10 +150,6 @@ void YouTubeProfileTab::onSubscribedChanged(bool subscribed) {
     m_subscriptionButton->setText(subscribed ? tr("Unsubscribe") : tr("Subscribe"));
 }
 
-void YouTubeProfileTab::showUserWebsite() {
-    QDesktopServices::openUrl(m_user.data()->websiteUrl());
-}
-
 void YouTubeProfileTab::showUploadDialog() {
     YouTubeUploadDialog *dialog = new YouTubeUploadDialog(this);
     dialog->open();
@@ -169,3 +168,9 @@ void YouTubeProfileTab::showWatchHistory() {
     window->setVideoFeed(YOUTUBE_WATCH_HISTORY_FEED);
     window->show();
 }
+
+void YouTubeProfileTab::parseActivatedLink(const QString &link) {
+    if (!ResourceLoader::instance()->display(link, false)) {
+        QDesktopServices::openUrl(link);
+    }
+}
