@@ -29,8 +29,6 @@ public:
     inline void setFooter(const QString &footer) { m_footer = footer; }
     inline QString timestamp() const { return m_timestamp; }
     inline void setTimestamp(const QString &timestamp) { m_timestamp = timestamp; }
-    inline QString action() const { return m_action; }
-    inline void setAction(const QString &action) { m_action = action; }
 
 private:
     QString m_id;
@@ -44,7 +42,6 @@ private:
     QString m_imagePathTwo;
     QString m_footer;
     QString m_timestamp;
-    QString m_action;
 };
 
 #endif // EVENT_H
